#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var commander_1 = __importDefault(require("commander"));
var runtime_1 = require("./runtime");
var chalk_1 = __importDefault(require("chalk"));
var sgts = function () {
    commander_1.default
        .version(require('../package.json').version)
        .option('-e, --endpoint <endpoint>', 'GraphQl Api endpoint')
        .option('-j, --json <json>', 'Json file of your GraphQL Api schema')
        .option('-o, --output <output>', 'Output path of your generated file')
        .option('-H, --headers <header>', 'Additional header option to fetch your schema from endpoint')
        .option('-p, --prefix <prefix>', 'Add prefix to all your types (ex: User becomes IUser with --suffix I)')
        .option('-s, --suffix <suffix>', 'Add suffix to all your types (ex: User becomes UserModel with --suffix Model)')
        .option('-G, --generateMethods', 'Generate all your graphQL methods fully typed (Inspired by Prisma)')
        .option('-A, --apolloHooks', 'Generate useMutation and useQuery hooks typed')
        .option('--onlyDefinition', 'Generate only the gql schema of the query')
        .option('-J, --jsMode', 'Generate the methods in Js with declaration files instead of Ts')
        .option('--customScalars <scalars>', 'Provide your custum scalars in format [{"myScalar": "MyType"} ...]')
        .parse(process.argv);
    var endpoint = commander_1.default.endpoint, json = commander_1.default.json, output = commander_1.default.output, customScalars = commander_1.default.customScalars, headers = commander_1.default.headers, prefix = commander_1.default.prefix, suffix = commander_1.default.suffix, generateMethods = commander_1.default.generateMethods, jsMode = commander_1.default.jsMode, onlyDefinition = commander_1.default.onlyDefinition, apolloHooks = commander_1.default.apolloHooks;
    if (customScalars) {
        try {
            customScalars = JSON.parse(customScalars);
        }
        catch (e) {
            console.error(chalk_1.default.red('Invalid custom scalars format, expected [{"myScalar": "MyType"} ...]'));
            return;
        }
    }
    try {
        runtime_1.sgtsGenerate({
            endpoint: endpoint,
            json: json,
            output: output,
            customScalars: customScalars,
            headers: headers,
            prefix: prefix,
            suffix: suffix,
            generateMethods: generateMethods,
            jsMode: jsMode,
            onlyDefinition: onlyDefinition,
            apolloHooks: apolloHooks,
        });
    }
    catch (e) {
        return;
    }
};
try {
    sgts();
}
catch (e) { }
