"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.withApolloTemplate = function (queries, mutations) {
    return "  import ApolloClient, { QueryOptions, OperationVariables, MutationOptions, ObservableQuery } from 'apollo-client';\n  import { execute } from 'apollo-link';\n  import { OperationDefinitionNode, DocumentNode } from 'graphql';\n  import graphQlTag from 'graphql-tag';\n\n\n  export type AbordableQueryWithArgs<T, A> = {\n    $args(args: A): AbordableQuery<T>;\n    $abort(): void;\n  };\n\n  export type AbordableQueryWithOptionalArgs<T, A> = {\n    $fetch(): Promise<T>;\n    $args(args: A): AbordableQuery<T>;\n    $abort(): void;\n  };\n  \n  export type AbordableQuery<T> = {\n    $fetch(): Promise<T>;\n    $abort(): void;\n  };\n  export interface FragmentableQueryWithArgs<T, A> {\n    $fragment(fragment: string | DocumentNode): AbordableQueryWithArgs<T, A>;\n  }\n  export interface FragmentableQueryWithOptionalArgs<T, A> {\n    $fragment(fragment: string | DocumentNode): AbordableQueryWithOptionalArgs<T, A>;\n  }\n  export interface FragmentableQuery<T> {\n    $fragment(fragment: string | DocumentNode): AbordableQuery<T>;\n  }\n  \n  export type AbordableMutationWithArgs<T, A> = {\n    $args(args: A): AbordableMutation<T>;\n    $abort(): void;\n  };\n\n  export type AbordableMutationWithOptionalArgs<T, A> = {\n    $post(): Promise<T>;\n    $args(args: A): AbordableMutation<T>;\n    $abort(): void;\n  };\n  \n  export type AbordableMutation<T> = {\n    $post(): Promise<T>;\n    $abort(): void;\n  };\n  \n  export interface FragmentableMutationWithArgs<T, A> {\n    $fragment(fragment: string | DocumentNode): AbordableMutationWithArgs<T, A>;\n  }\n  export interface FragmentableMutationWithOptionalArgs<T, A> {\n    $fragment(fragment: string | DocumentNode): AbordableMutationWithOptionalArgs<T, A>;\n  }\n  export interface FragmentableMutation<T> {\n    $fragment(fragment: string | DocumentNode): AbordableMutation<T>;\n  }\n  \n  \n  const guessFragmentType = (fragment: string | DocumentNode) => {\n    let isString,\n      isFragment = false;\n    let fragmentName = '';\n    if (typeof fragment === 'string') {\n      isString = true;\n    } else if (typeof fragment === 'object' && fragment.definitions.length) {\n      isFragment = true;\n      const definition = fragment.definitions[0];\n      if (definition.kind === 'FragmentDefinition') {\n        fragmentName = definition.name.value;\n      } else {\n        console.error(\n          `The argument passed is not a fragment definition, got ${definition.kind} instead`\n        );\n        return;\n      }\n    }\n    return { isString, isFragment, fragmentName };\n  };\n  \n  export const apiProvider = (apolloClient: ApolloClient<any>) => {\n    const abortableQuery = <T, A = null>(\n      query: DocumentNode,\n      args: boolean\n    ): A extends null ? AbordableQuery<T> : AbordableQueryWithArgs<T, A> => {\n      let observableQuery: ZenObservable.Subscription;\n      const parsedQuery = query.definitions[0] as OperationDefinitionNode;\n      const queryName = parsedQuery.name.value;\n      let variables: { [x: string]: any } = {};\n  \n      function $abort() {\n        if (observableQuery && !observableQuery.closed) {\n          observableQuery.unsubscribe();\n        }\n      }\n      async function $fetch() {\n        return new Promise<T>((resolve, reject) => {\n          observableQuery = execute(apolloClient.link, {\n            query,\n            variables,\n          }).subscribe({\n            next: ({ data, errors }) => {\n              if (data) {\n                resolve(data[queryName]);\n              } else {\n                reject(errors);\n              }\n            },\n            error: error => reject(error),\n          });\n        });\n      }\n      function $args(args) {\n        variables = args;\n        return {\n          $abort,\n          $fetch,\n        };\n      }\n      if (args) {\n        return {\n          $abort,\n          $args,\n        } as any;\n      } else {\n        return {\n          $abort,\n          $fetch,\n        } as any;\n      }\n    };\n    const abortableMutation = <T, A = null>(\n      mutation: DocumentNode,\n      args: boolean\n    ): AbordableMutationWithArgs<T, A> => {\n      let observableQuery: ZenObservable.Subscription;\n      const parsedQuery = mutation.definitions[0] as OperationDefinitionNode;\n      const mutationName = parsedQuery.name.value;\n      let variables: { [x: string]: any } = {};\n  \n      function $abort() {\n        if (observableQuery && !observableQuery.closed) {\n          observableQuery.unsubscribe();\n        }\n      }\n      async function $post() {\n        return new Promise<T>((resolve, reject) => {\n          observableQuery = execute(apolloClient.link, {\n            query: mutation,\n            variables,\n          }).subscribe({\n            next: ({ data, errors }) => {\n              if (data) {\n                resolve(data[mutationName]);\n              } else {\n                reject(errors);\n              }\n            },\n            error: error => reject(error),\n          });\n        });\n      }\n      function $args(args) {\n        variables = args;\n        return {\n          $abort,\n          $post,\n        };\n      }\n      if (args) {\n        return {\n          $abort,\n          $args,\n        } as any;\n      } else {\n        return {\n          $abort,\n          $post,\n        } as any;\n      }\n    };\n\n    return {\n      " + queries.join('\n') + "\n      " + mutations.join('\n') + "\n    }\n  };\n\n  ";
};
